#!/usr/bin/python3
from PyQt5 import QtCore, QtDBus

global name; name = "obsuite"


class QDBusObject(QtCore.QObject):
    def __init__(self, parent):
        QtCore.QObject.__init__(self)
        self.__dbusAdaptor = QDBusServerAdapter(self, parent)
        self.start()

    def start(self):
        bus = QtDBus.QDBusConnection.sessionBus()
        bus.registerObject(f"/org/{name}/session", self)
        bus.registerService(f"org.{name}.session")
        return bus


class QDBusServerAdapter(QtDBus.QDBusAbstractAdaptor):
    QtCore.Q_CLASSINFO("D-Bus Interface", f"org.{name}.session")
    QtCore.Q_CLASSINFO("D-Bus Introspection",
    f'<interface name="org.{name}.session">\n'
    '  <method name="parse">\n'
    '    <arg direction="in" type="s" name="cmd"/>\n'
    '  </method>\n'
    '</interface>\n')

    def __init__(self, server, parent):
        super().__init__(server)
        self.parent = parent

    @QtCore.pyqtSlot(str)
    def parse(self, cmd):
        # Serialize the string of commands
        if cmd:
            commands = {}
            current = ""
            for arg in cmd.split("%"):
                if arg.startswith("-"):
                    current = arg.lstrip("-")
                elif current:
                    commands[current].append(arg)
                if current not in commands:
                    commands[current] = []
            self.parent.parseCommands(commands)
